package com.srs.comprehensive.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.common.core.domain.AjaxResult;
import com.srs.comprehensive.domain.CphIdeologyScore;

/**
 * 思想品德初始分数Service接口
 *
 * @author srs
 * @date 2024-07-01
 */
public interface ICphIdeologyScoreService extends IService<CphIdeologyScore> {


    public AjaxResult doInit();

    /**
     * 查询思想品德初始分数
     *
     * @param id 思想品德初始分数主键
     * @return 思想品德初始分数
     */
    public CphIdeologyScore selectCphIdeologyScoreById(Long id);

    /**
     * 查询思想品德初始分数列表
     *
     * @param cphIdeologyScore 思想品德初始分数
     * @return 思想品德初始分数集合
     */
    List<CphIdeologyScore> selectCphIdeologyScoreList(CphIdeologyScore cphIdeologyScore);

    /**
     * 新增思想品德初始分数
     *
     * @param cphIdeologyScore 思想品德初始分数
     * @return 结果
     */
    int insertCphIdeologyScore(CphIdeologyScore cphIdeologyScore);

    /**
     * 修改思想品德初始分数
     *
     * @param cphIdeologyScore 思想品德初始分数
     * @return 结果
     */
    int updateCphIdeologyScore(CphIdeologyScore cphIdeologyScore);

    /**
     * 批量删除思想品德初始分数
     *
     * @param ids 需要删除的思想品德初始分数主键集合
     * @return 结果
     */
    int deleteCphIdeologyScoreByIds(Long[] ids);

    /**
     * 删除思想品德初始分数信息
     *
     * @param id 思想品德初始分数主键
     * @return 结果
     */
    int deleteCphIdeologyScoreById(Long id);
}
